Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(5465)

Unified Diff: chrome/browser/process_singleton_uitest.cc

Issue 8574030: base::Bind() conversion for ProcessSingletonTest (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 9 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/process_singleton_uitest.cc
diff --git a/chrome/browser/process_singleton_uitest.cc b/chrome/browser/process_singleton_uitest.cc
index d96aee91ab4bca017b05c1b55f0f5204ce0b3dfa..70f81615a0e980e399776176bbbebc2ef6bf49e9 100644
--- a/chrome/browser/process_singleton_uitest.cc
+++ b/chrome/browser/process_singleton_uitest.cc
@@ -12,6 +12,7 @@
#include <list>
+#include "base/bind.h"
#include "base/file_path.h"
#include "base/file_util.h"
#include "base/memory/ref_counted.h"
@@ -33,7 +34,7 @@ namespace {
// This is for the code that is to be ran in multiple threads at once,
// to stress a race condition on first process start.
// We use the thread safe ref counted base class so that we can use the
// NewRunnableMethod class to run the StartChrome methods in many threads.
class ChromeStarter : public base::RefCountedThreadSafe<ChromeStarter> {
public:
ChromeStarter(int timeout_ms, const FilePath& user_data_dir)
@@ -256,10 +257,10 @@ TEST_F(ProcessSingletonTest, MAYBE_StartupRaceCondition) {
chrome_starter_threads_[i]->message_loop());
chrome_starter_threads_[i]->message_loop()->PostTask(
- FROM_HERE, NewRunnableMethod(chrome_starters_[i].get(),
- &ChromeStarter::StartChrome,
- &threads_waker_,
- first_run));
+ FROM_HERE, base::Bind(&ChromeStarter::StartChrome,
+ chrome_starters_[i].get(),
+ &threads_waker_,
+ first_run));
}
// Wait for all the starters to be ready.
« no previous file with comments | « no previous file | no next file » | no next file with comments »
@@ -33,7 +34,7 @@ namespace {
// to stress a race condition on first process start.
// We use the thread safe ref counted base class so that we can use the
-// NewRunnableMethod class to run the StartChrome methods in many threads.
+// base::Bind to run the StartChrome methods in many threads.
class ChromeStarter : public base::RefCountedThreadSafe<ChromeStarter> {
public:

Powered by Google App Engine
This is Rietveld 408576698